import 'package:equatable/equatable.dart';
import 'package:furima_item_search/query_condition.dart';
import 'package:furima_item_search/site.dart';

class Query extends Equatable {
  Query(
      {this.id,
      this.name,
      this.keyword,
      this.deliveryType,
      this.saleStatus,
      this.sites,
      this.sortOrder,
      this.priceMin,
      this.priceMax,
      this.isEnabled,
      this.isRegistered})
      : super([
          id,
          name,
          keyword,
          deliveryType,
          saleStatus,
          sites,
          sortOrder,
          priceMin,
          priceMax,
          isEnabled,
          isRegistered
        ]);

  int id;
  String name;
  String keyword;
  DeliveryType deliveryType;
  SaleStatus saleStatus;
  List<Site> sites;
  SortOrder sortOrder;
  int priceMin;
  int priceMax;
  bool isEnabled;
  bool isRegistered;

  factory Query.initial() {
    return Query(
        name: '',
        keyword: '',
        deliveryType: DeliveryType.all,
        saleStatus: SaleStatus.all,
        sites: Site.values,
        sortOrder: SortOrder.recommended,
        isEnabled: false,
        isRegistered: false);
  }

  Query copyWith(
      {String name,
      String keyword,
      DeliveryType deliveryType,
      SaleStatus saleStatus,
      List<Site> sites,
      SortOrder sortOrder,
      int priceMin,
      int priceMax,
      bool isEnabled,
      bool isRegistered}) {
    return Query(
      id: this.id,
      name: name ?? this.name,
      keyword: keyword ?? this.keyword,
      deliveryType: deliveryType ?? this.deliveryType,
      saleStatus: saleStatus ?? this.saleStatus,
      sites: sites ?? this.sites,
      sortOrder: sortOrder ?? this.sortOrder,
      priceMin: priceMin ?? this.priceMin,
      priceMax: priceMax ?? this.priceMax,
      isEnabled: isEnabled ?? this.isEnabled,
      isRegistered: isRegistered ?? this.isRegistered,
    );
  }

  String parameter(Site site) {
    String parameter;
    switch (site) {
      case Site.mercari:
        parameter = 'keyword=' + keyword.trim().replaceAll(' ', '+');
        if (priceMin != null) {
          parameter += '&price_min=' + priceMin.toString();
        }
        if (priceMax != null) {
          parameter += '&price_max=' + priceMax.toString();
        }
        break;
      case Site.rakuma:
        parameter = 'query=' + keyword.trim();
        if (priceMin != null) {
          parameter += '&min=' + priceMin.toString();
        }
        if (priceMax != null) {
          parameter += '&max=' + priceMax.toString();
        }
        break;
      case Site.yahoo:
        parameter =
            'price_type=currentprice&p=' + keyword.trim().replaceAll(' ', '+');
        if (priceMin != null) {
          parameter += '&min=' + priceMin.toString();
        }
        if (priceMax != null) {
          parameter += '&max=' + priceMax.toString();
        }
        break;
    }
    parameter += SaleStatusHelper.parameter(site, saleStatus) +
        DeliveryTypeHelper.parameter(site, deliveryType) +
        SortOrderHelper.parameter(site, sortOrder);
    return parameter;
  }
}
