import 'package:furima_item_search/site.dart';

enum SaleStatus { all, onSale, sole }

class SaleStatusHelper {
  static String getName(SaleStatus saleStatus) {
    switch (saleStatus) {
      case SaleStatus.all:
        return 'すべて';
      case SaleStatus.onSale:
        return '販売中のみ';
      case SaleStatus.sole:
        return '売切れのみ';
    }
  }

  static String parameter(Site site, SaleStatus saleStatus) {
    switch (site) {
      case Site.mercari:
        switch (saleStatus) {
          case SaleStatus.all:
            return '&status_all=1';
          case SaleStatus.onSale:
            return '&status_on_sale=1';
          case SaleStatus.sole:
            return '&status_trading_sold_out=1';
        }
        break;
      case Site.rakuma:
        switch (saleStatus) {
          case SaleStatus.all:
            return '';
          case SaleStatus.onSale:
            return '&transaction=selling';
          case SaleStatus.sole:
            return '&transaction=soldout';
        }
        break;
      default:
        return '';
    }
  }
}

enum DeliveryType { all, included }

class DeliveryTypeHelper {
  static String getName(DeliveryType type) {
    switch (type) {
      case DeliveryType.all:
        return 'すべて';
      case DeliveryType.included:
        return '送料込みのみ';
    }
  }

  static String parameter(Site site, DeliveryType type) {
    switch (site) {
      case Site.mercari:
        switch (type) {
          case DeliveryType.all:
            return '&shipping_payer_all=1';
          case DeliveryType.included:
            return '&shipping_payer_id%5B2%5D=1';
        }
        break;
      case Site.rakuma:
        switch (type) {
          case DeliveryType.all:
            return '';
          case DeliveryType.included:
            return '&carriage=1';
        }
        break;
      default:
        return '';
    }
  }
}

enum SortOrder { recommended, priceDesc, priceAsc, createdDesc, likeCountDesc }

class SortOrderHelper {
  static String getName(SortOrder type) {
    switch (type) {
      case SortOrder.recommended:
        return 'おすすめ順';
      case SortOrder.priceAsc:
        return '安い順';
      case SortOrder.priceDesc:
        return '高い順';
      case SortOrder.createdDesc:
        return '新着順';
      case SortOrder.likeCountDesc:
        return 'いいねの多い順';
    }
  }

  static String parameter(Site site, SortOrder sortOrder) {
    switch (site) {
      case Site.mercari:
        switch (sortOrder) {
          case SortOrder.recommended:
            return '&sort_order=';
          case SortOrder.priceAsc:
            return '&sort_order=price_asc';
          case SortOrder.priceDesc:
            return '&sort_order=price_desc';
          case SortOrder.likeCountDesc:
            return '&sort_order=like_desc';
          case SortOrder.createdDesc:
            return '&sort_order=created_desc';
        }
        break;
      case Site.rakuma:
        switch (sortOrder) {
          case SortOrder.recommended:
            return '&sort=relevance&order=desc';
          case SortOrder.priceAsc:
            return '&sort=sell_price&order=asc';
          case SortOrder.priceDesc:
            return '&sort=sell_price&order=desc';
          case SortOrder.likeCountDesc:
            return '&sort=like_count&order=desc';
          case SortOrder.createdDesc:
            return '&sort=item_id&order=desc';
        }
        break;
      case Site.yahoo:
        switch (sortOrder) {
          case SortOrder.recommended:
            return '&s1=score2&o1=d';
          case SortOrder.priceAsc:
            return '&s1=cbids&o1=a';
          case SortOrder.priceDesc:
            return '&s1=cbids&o1=d';
          case SortOrder.likeCountDesc:
            return '&s1=bids&o1=d';
          case SortOrder.createdDesc:
            return '&s1=new&o1=d';
        }
        break;
    }
  }
}
